import { IConfig } from './iconfig';
/**
 * Class to show device rotation fullscreen prompt, it activates immediately upon instantiation
 */
export declare class DeviceRotationPrompt {
    /**
     * Class config
     * @private
     */
    private readonly config;
    /**
     * Check orientation fn reference to be able to add and also remove event listener
     * @private
     */
    private readonly checkOrientationFn;
    /**
     * Constructor of class
     * @param config - to configure class, if configuration option is omitted, default one is used
     */
    constructor(config?: IConfig);
    /**
     * Method to destroy all created html/css elements and also remove event listener for orientation detection, handy when you do not want to use library anymore
     */
    destroy(): void;
    /**
     * Method to determine, if library and all functionality can be initialized
     * @private
     */
    private canInitialize;
    /**
     * Method to generate HTML elements like main fullscreen div container, svg image and also description text
     * @private
     */
    private generateHtml;
    /**
     * Method to generate styles for generated HTML elements
     * @private
     */
    private generateStyles;
    /**
     * z-index rule for css, if zIndex property is present in config
     * @private
     */
    private get zIndexRule();
    /**
     * Animation css styles, @keyframes
     * @private
     */
    private get animationStyle();
    /**
     * Method to find if current orientation is desired one
     * @returns true if orientation is same as you desire, false otherwise
     * @private
     */
    private isDesiredOrientation;
    /**
     * Method to show/hide whole prompt
     * @private
     */
    private checkOrientation;
    /**
     * Size of image, returns size from config, or if image size is not presented in config it returns 60vh for portrait, 30vh for landscape
     * @private
     */
    private get imageSize();
    /**
     * Size of text, returns size from config, or if text size is not presented in config it returns 10vh for portrait, 5vh for landscape
     * @private
     */
    private get textSize();
    /**
     * Initial angle of image, if animation is disabled, it returns final angle
     * @private
     */
    private get initialAngle();
    /**
     * Final angle of image
     * @private
     */
    private get finalAngle();
    /**
     * Return display CSS property based on hideText property
     * @private
     */
    private get isTextHidden();
    /**
     * Return display CSS property based on hideImage property
     * @private
     */
    private get isImageHidden();
    /**
     * Device SVG image
     * @private
     */
    private get deviceSvg();
    /**
     * Get phone svg style based on imageStyle property
     * @private
     */
    private get svgStyle();
    /**
     * Detect if is mobile/tablet platform or not
     * @private
     */
    private isMobile;
}
